package com.bigflix.BigFlixMovies;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.Window;
import android.widget.Button;
import android.widget.EditText;
import android.widget.TextView;

import android.widget.Toast;
import com.app.pokktsdk.*;
import com.app.pokktsdk.model.VideoResponse;
import com.app.util.Comman;
import com.pokkt.videodemo.R;

public class VideoActivity extends Activity {
	float points = 0.00F;
    float videoValue = 0.00F;
	EditText edt_points;
	Button btnIncent, btnNonIncent, btnWithoutIntent;
	PokktManager pokktManager;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		requestWindowFeature(Window.FEATURE_NO_TITLE);
		super.onCreate(savedInstanceState);

		setContentView(R.layout.video);

		if(!Comman.isNetworkAvailable(this)){
			Toast.makeText(this, "Network Not Available!! Please Connect to Internet First.", Toast.LENGTH_LONG).show();
			finish();
		}

		pokktManager = MyApp.getPokktManager(this);
        setVideoDisplayedListener();
        setVideoClosedListener();
        setVideoSkippedListener();
        setVideoGratifiedListener();
        setVideoCompletedListener();


		pokktManager.setSkipVideo(true);
		PokktManager.setDebug(true);
        pokktManager.setDefaultSkipTime(10);

        // this will be a unique id per user from developer side
        // developer is free to choose any String data point.
        pokktManager.setThirdPartyUserId("123456");

		btnIncent = (Button) findViewById(R.id.button_video);
		btnNonIncent = (Button) findViewById(R.id.button_video_non_incent);
		btnWithoutIntent = (Button) findViewById(R.id.button_video_without_intent);

		btnIncent.setOnClickListener(new OnClickListener() {
			@Override
			public void onClick(View v) {
				pokktManager.playVideoCampaign(true, "PokktSample");
				finish();
			}
		});

		btnNonIncent.setOnClickListener(new OnClickListener() {
			@Override
			public void onClick(View v) {
				pokktManager.playVideoCampaign(false, "PokktSample");
				finish();
			}
		});

		btnWithoutIntent.setOnClickListener(new OnClickListener() {
			@Override
			public void onClick(View v) {
				if (pokktManager.isVideoAvailable()) {
					pokktManager.playVideoCampaign(false, "PokktSample");
				} else {
					startActivity(new Intent(VideoActivity.this,
							VideoNextActivity.class));
				}
				finish();
			}
		});

		if (!pokktManager.isVideoAvailable()) {
			pokktManager
					.setDownloadCompletionlListener(new DownloadCompleteListener() {
						@Override
						public void onDownloadCompletion(float result) {
							videoValue = result;
							// getSharedPreferences("MyPrefs",
							// MODE_PRIVATE).edit()
							// .putInt("vc", videoValue).commit();
							showButtons();
						}
						@Override
						public void onDownloadFailed(String message) {
							// show toast
							Toast.makeText(VideoActivity.this, "video download error: " + message,
									Toast.LENGTH_LONG).show();
						}
					});
		} else {
			// videoValue = getSharedPreferences("MyPrefs",
			// MODE_PRIVATE).getInt(
			// "vc", 0);
			videoValue = pokktManager.getVideoVc();
			showButtons();
		}

		if (points == 0)
			points = getSharedPreferences("MyPrefs", MODE_PRIVATE).getFloat(
					"points", 0);
		updateUI();
	}

	void setVideoGratifiedListener() {
		pokktManager.setVideoGratifiedListener(new VideoGratifiedListener() {
            @Override
            public void onVideoGratified(VideoResponse videoResponse) {
                if ("1".equalsIgnoreCase(videoResponse.getCoinStatus())) {
                    if (!"".equalsIgnoreCase(videoResponse.getTransactionId()))
                        Toast.makeText(
                                VideoActivity.this,
                                "Points earned " + videoResponse.getCoins()
                                        + " with transaction id "
                                        + videoResponse.getTransactionId(), Toast.LENGTH_LONG)
                                .show();
                    else
                        Toast.makeText(VideoActivity.this, "Points earned " + videoResponse.getCoins(),
                                Toast.LENGTH_LONG).show();
                    updatePoints(Float.parseFloat(videoResponse.getCoins()));
                }
            }
        });
	}

	void setVideoClosedListener() {
		pokktManager.setVideoClosedListener(new VideoClosedListener() {
			@Override
			public void onVideoClosed(boolean backPressed) {
                if(backPressed){
                    Toast.makeText(VideoActivity.this, "Video Closed with Back Button",
                            Toast.LENGTH_LONG).show();
                }else{
                    Toast.makeText(VideoActivity.this, "Video Closed",
                            Toast.LENGTH_LONG).show();
                }
			}
		});
	}

	void setVideoDisplayedListener() {
		pokktManager.setVideoDisplayedListener(new VideoDisplayedListener() {
			@Override
			public void onVideoDisplayed() {
				Toast.makeText(VideoActivity.this, "Video Displayed",
						Toast.LENGTH_LONG).show();
			}
		});
	}


	void setVideoSkippedListener() {
		pokktManager.setVideoSkippedListener(new VideoSkippedListener() {
			@Override
			public void onVideoSkipped() {
				Toast.makeText(VideoActivity.this, "Video Skipped",
						Toast.LENGTH_LONG).show();
			}
		});
	}

    void setVideoCompletedListener() {
        pokktManager.setVideoCompletedListener(new VideoCompletedListener() {
            @Override
            public void onVideoCompleted() {
                Toast.makeText(VideoActivity.this, "Video Completed",
                        Toast.LENGTH_LONG).show();
            }
        });
    }

	@Override
	protected void onResume() {
	//	pokktManager = PokktManager.getInstance(this);
		if (!pokktManager.isVideoAvailable()) {
			hideButtons();
			pokktManager
					.setDownloadCompletionlListener(new DownloadCompleteListener() {
						@Override
						public void onDownloadCompletion(float result) {
							videoValue = result;
							// getSharedPreferences("MyPrefs",
							// MODE_PRIVATE).edit()
							// .putInt("vc", videoValue).commit();
							showButtons();
						}
						@Override
						public void onDownloadFailed(String message) {
							// show toast
							Toast.makeText(VideoActivity.this, "video download error: " + message,
									Toast.LENGTH_LONG).show();
						}
					});
		}else {
            videoValue = pokktManager.getVideoVc();
        }
		super.onResume();
	}

	void updateUI() {
		((TextView) findViewById(R.id.points)).setText("Points earned: "
				+ points);
		getSharedPreferences("MyPrefs", MODE_PRIVATE).edit()
				.putFloat("points", points).commit();
	}

	private void showButtons() {
		btnIncent.setText("Play Incent Vdo To Earn " + videoValue);
		btnIncent.setVisibility(View.VISIBLE);
		btnNonIncent.setVisibility(View.VISIBLE);
	}

	private void hideButtons() {
		btnIncent.setVisibility(View.GONE);
		btnNonIncent.setVisibility(View.GONE);
	}

	@Override
	protected void onDestroy() {
		super.onDestroy();
	}

	public void updatePoints(float points) {
		if (points == -1.00F) {
            // no points to be given.
		} else {
			this.points = this.points + points;
			updateUI();
		}
	}
}
